==> includable-1.17.0.tgz: package/lib/containers/Container.js <==
/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const output = require('../output')
const path = require('path')
const fs = require('fs')

const ContainerConfig = require('./ContainerConfig')
const Boxes = require('./Boxes')

var Container = {}

/**
 * Get the version of the container metadata stored in the current directory (if any).
 *
 * @returns {int|boolean}
 */
Container.getVersion = function () {
  if (!fs.existsSync(path.join('.inc', 'version'))) {
    if (fs.existsSync('.scho' + 'lica')) {
      return 10
    }
    return false
  }

  return parseInt(fs.readFileSync(path.join('.inc', 'version'), 'utf8'), 10) || false
}

/**
 * Remove the default container config file.
 */
Container.clean = function () {
  try {
    fs.unlinkSync(path.join('.inc', 'containers', 'default.json'))
  } catch (e) {
    // Do nothing
  }
}

/**
 * Perform a container metadata structure upgrade (if necessary).
 */
Container.performUpgrade = function () {
  var version = this.getVersion()
  if (!version) {
    return
  }

  output.debug('Checking if we need to update the container structure')
  output.debug('Current container version:', version)

  if (version > global.containerVersion) {
    output.warn('Warning: project metadata is created using a newer version of the CLI, please upgrade')
    return
  }

  if (version < global.containerVersion) {
    var upgradeFile = path.join(global.base, 'lib', 'upgrades', version + '-' + global.containerVersion + '.js')
    try {
      if (!fs.existsSync(upgradeFile)) {
        throw new Error('no upgrade path from version ' + version + ' to ' + global.containerVersion)
      }
      require(upgradeFile)()
      output.warn('Upgraded project metadata from ' + version + ' to ' + global.containerVersion)
    } catch (e) {
      output.warn('Error upgrading project: ' + e.message)
    }
    return
  }

  output.debug('No need to update container structure')
}

/**
 * Read a container config file. If the file with the supplied container name doesn't exist,
 * this falls back to the 'default' container, if that one exists.
 *
 * @param {string} name
 * @param {function(Error, ContainerConfigObject)} cb
 */
Container.getConfig = function (name, cb) {
  ContainerConfig.read(name, cb)
}

/**
 * Create a new Includable cloud instance (dev mode).
 *
 * @param {RunOptions} options
 * @param {function(Error, BoxCreateResult)} callback
 */
Container.create = function (options, callback) {
  Boxes.create(options, callback)
}

module.exports = Container

==> includable-1.18.0.tgz: package/lib/containers/Container.js <==
/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const output = require('../output')
const path = require('path')
const fs = require('fs')

const ContainerConfig = require('./ContainerConfig')
const Boxes = require('./Boxes')

const Container = {}

/**
 * Get the version of the container metadata stored in the current directory (if any).
 *
 * @returns {int|boolean}
 */
Container.getVersion = function () {
  if (!fs.existsSync(path.join('.inc', 'version'))) {
    if (fs.existsSync('.scho' + 'lica')) {
      return 10
    }
    return false
  }

  return parseInt(fs.readFileSync(path.join('.inc', 'version'), 'utf8'), 10) || false
}

/**
 * Remove the default container config file.
 */
Container.clean = function () {
  try {
    fs.unlinkSync(path.join('.inc', 'containers', 'default.json'))
  } catch (e) {
    // Do nothing
  }
  try {
    fs.unlinkSync(path.join('.inc', 'containers', 'beta.json'))
  } catch (e) {
    // Do nothing
  }
}

/**
 * Perform a container metadata structure upgrade (if necessary).
 */
Container.performUpgrade = function () {
  const version = this.getVersion()
  if (!version) {
    return
  }

  output.debug('Checking if we need to update the container structure')
  output.debug('Current container version:', version)

  if (version > global.containerVersion) {
    output.warn('Warning: project metadata is created using a newer version of the CLI, please upgrade')
    return
  }

  if (version < global.containerVersion) {
    const upgradeFile = path.join(global.base, 'lib', 'upgrades', version + '-' + global.containerVersion + '.js')
    try {
      if (!fs.existsSync(upgradeFile)) {
        output.warn('Error upgrading project: no upgrade path from version ' +
          version + ' to ' + global.containerVersion)
        return
      }
      require(upgradeFile)()
      output.warn('Upgraded project metadata from ' + version + ' to ' + global.containerVersion)
    } catch (e) {
      output.warn('Error upgrading project: ' + e.message)
    }
    return
  }

  output.debug('No need to update container structure')
}

/**
 * Read a container config file. If the file with the supplied container name doesn't exist,
 * this falls back to the 'default' container, if that one exists.
 *
 * @param {string} name
 * @param {function(Error, Object)} cb
 */
Container.getConfig = function (name, cb) {
  ContainerConfig.read(name, cb)
}

/**
 * Create a new Includable cloud instance (dev mode).
 *
 * @param {Object} options
 * @param {function(Error, Object)} callback
 */
Container.create = function (options, callback) {
  Boxes.create(options, callback)
}

module.exports = Container
